@@ -15,6 +15,10 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
+from datetime import date
+
+from numpy.testing import assert_almost_equal
+
 from rqalpha.environment import Environment
 
 from ..utils import make_test_strategy_decorator
@@ -69,7 +73,7 @@ def test_future_info():
 
     def on_trade(_, event):
         trade = event.trade
-        contract_multiplier = Environment.get_instance().data_proxy.instruments("SC1809").contract_multiplier
+        contract_multiplier = Environment.get_instance().data_proxy.instrument("SC1809").contract_multiplier
         if trade.position_effect == POSITION_EFFECT.OPEN:
             assert_almost_equal(
                 trade.transaction_cost, 0.0002 * trade.last_quantity * trade.last_price * contract_multiplier
@@ -84,7 +88,7 @@ def test_future_info():
     return locals()
 
 
-def test_position():
+def test_init_position():
     __config__ = {
         "base": {
             "accounts": {
@@ -94,6 +98,13 @@ def test_position():
         },
    }
 
+    def before_trading(context):
+        if context.now.date() == date(2018, 4, 2):
+            # 首个交易日，持仓价格应为昨收
+            pos = get_position("000006.XSHE")  # noqa
+            assert_almost_equal(pos.last_price, 7.37)
+            assert pos.quantity == 10000
+
     def init(context):
         context.f1 = "000006.XSHE"
         stock_position = context.portfolio.get_position('000006.XSHE', 'LONG')
